==> node-rollup-plugin-replace_2.3.3%2B~2.2.0.orig.tar.xz: node-rollup-plugin-replace-2.3.3/.github/ISSUE_TEMPLATE/BUG.md <==
---
name: 🐞 Bug Report
about: Something went awry and you'd like to tell us about it.

---

<!--
  ⚡️ katchow! We 💛 issues.

  Please - do not - remove this template.
  Please - do not - skip or remove parts of this template.
  Or your issue may be closed.

  👉🏽 Need help or tech support? Please don't open an issue!
  Head to https://gitter.im/rollup/rollup or https://stackoverflow.com/questions/tagged/rollupjs

  ❤️ Rollup? Please consider supporting our collective:
  👉 https://opencollective.com/rollup/donate
-->

- Rollup Plugin Name: <!-- the plugin(s) this issue is about -->
- Rollup Plugin Version:
- Rollup Version:
- Operating System (or Browser):
- Node Version:

### How Do We Reproduce?

<!--
  Issues without minimal reproductions will be closed! Please provide one by:
  1. Using the REPL.it plugin reproduction template at https://repl.it/@rollup/rollup-plugin-repro
  2. Provide a minimal repository link (Read https://git.io/fNzHA for instructions).
     Please use NPM for installing dependencies!
     These may take more time to triage than the other options.
  3. Using the REPL at https://rollupjs.org/repl/, or
-->


### Expected Behavior


### Actual Behavior


<!--
  Most issues can be expressed or demonstrated through the REPL or a repository.
  However, the situation may arise where some small code snippets also need to
  be provided. In that situation, please add your code below using
  Fenced Code Blocks (https://help.github.com/articles/creating-and-highlighting-code-blocks/)
-->

==> node-rollup-plugin-replace_2.3.4%2B~2.2.0.orig.tar.xz: node-rollup-plugin-replace-2.3.4/.github/ISSUE_TEMPLATE/BUG.md <==
---
name: 🐞 Bug Report
about: Something went awry and you'd like to tell us about it.

---

<!--
  ⚡️ katchow! We 💛 issues.

  🚨 Your issue will be CLOSED if:
     - This template is removed
     - Parts of this template are removed

  👉🏽 Need help or tech support? Please don't open an issue!
  Head to https://gitter.im/rollup/rollup or https://stackoverflow.com/questions/tagged/rollupjs

  ❤️ Rollup? Please consider supporting our collective:
  👉 https://opencollective.com/rollup/donate
-->

- Rollup Plugin Name: <!-- the plugin(s) this issue is about -->
- Rollup Plugin Version:
- Rollup Version:
- Operating System (or Browser):
- Node Version:
- Link to reproduction _(⚠️ read below)_:

<!--
  🚨 Issues WITHOUT a valid reproduction WILL BE CLOSED!

  Please provide one by:
  1. Using the REPL.it plugin reproduction template at https://repl.it/@rollup/rollup-plugin-repro
  2. Provide a minimal repository link (Read https://git.io/fNzHA for instructions).
     Please use NPM for installing dependencies!
     These may take more time to triage than the other options.
  3. Using the Rollup REPL at https://rollupjs.org/repl/

  ⚠️ ZIP Files are unsafe and maintainers will NOT download them.
-->


### Expected Behavior


### Actual Behavior


### Additional Information

<!--
  Most issues can be expressed or demonstrated through the REPL or a repository.
  However, the situation may arise where some small code snippets also need to
  be provided. In that situation, please add your code below using
  Fenced Code Blocks (https://help.github.com/articles/creating-and-highlighting-code-blocks/)
-->
